@@ -431,7 +431,7 @@ class BigBoardPanel(dbus.service.Object):
         self.__unpopout_button.connect("activated", lambda button: self.__do_unpopout())
         self._header_box.append(self.__unpopout_button, hippo.PACK_END)
      
-        self._title = hippo.CanvasText(classes='header', text="My Desktop", font="Bold 14px", xalign=hippo.ALIGNMENT_START, padding_left=8)
+        self._title = hippo.CanvasText(classes='header', text="My Desktop", font="Bold", xalign=hippo.ALIGNMENT_START, padding_left=8)
      
         self._header_box.append(self._title, hippo.PACK_EXPAND)
         
